using System;
using System.Collections.Generic;
using System.Data;
using System.Drawing;
using System.Text;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using BlackTieMedical.Entity;
using BlackTieMedical.Entity.Manager;

namespace BlackTieMedical
{
    public partial class POProductsList : BasePage
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            tdCharts.Visible = false;

            if(!Page.IsPostBack)
            {
                // before we do anything make sure the user is logged in 
                // redirect to login if the user is not logged in
                if (Global.CurrentUser == null)
                {
                    Response.Redirect("Login.aspx?ReturnUrl=" + Request.Url);
                } 

                ViewState["Hospital"] = 0;
                ViewState["Department"] = 0;

                if (Request.Cookies["ddlHospital"] != null && Request.Cookies["ddlHospital"].Value != null)
                {
                    cddHospital.SelectedValue = Request.Cookies["ddlHospital"].Value;
                    ViewState["Hospital"] = Convert.ToInt64(Request.Cookies["ddlHospital"].Value);
                }

                if (Request.Cookies["ddlDepartment"] != null)
                {
                    cddDepartment.SelectedValue = Request.Cookies["ddlDepartment"].Value;
                    ViewState["Department"] = Convert.ToInt64(Request.Cookies["ddlDepartment"].Value);
                }

                ViewState["SortCol"] = 2;
                ViewState["SortOrder"] = "DESC";

                if (Request["po"] != null)
                {
                    ViewState["po"] = Request["po"];

                    switch (ViewState["po"].ToString())
                    {
                        case "i":
                            lblHeading.Text = "View Approved Purchase Orders";
                            break;
                        case "p":
                            lblHeading.Text = "View Pending Bill-Only Requisitions";
                            break;
                        case "d":
                            lblHeading.Text = "View Declined Bill-Only Requisitions";
                            break;
                    }
                }

                RefreshGrid();
            }
        }

        private void RefreshGrid()
        {
            if (Convert.ToInt64(ViewState["Hospital"]) <= 0 || Convert.ToInt64(ViewState["Department"]) <= 0)
            {
                rptPOs.DataBind();
                tdCharts.Visible = false;
            }
            else
            {
                List<POProductRequisition> lstPOProductRequisition = null;

                if (Global.CurrentUser.UserTypeID == (int)Entity.User.UserType.HospitalUser)
                {
                    lstPOProductRequisition =
                        POProductRequisitionManager.GetPOProductRequisitionsByHospitalDepartment(
                            Convert.ToInt64(ViewState["Hospital"]),
                            Convert.ToInt64(ViewState["Department"]), Global.CurrentUser.UserID);
                }
                else if (Global.CurrentUser.UserTypeID == (int)Entity.User.UserType.VendorUser)
                {
                    lstPOProductRequisition =
                        POProductRequisitionManager.GetPOProductReqsByHospitalDepartmentManu(
                            Convert.ToInt64(ViewState["Hospital"]),
                            Convert.ToInt64(ViewState["Department"]), Global.CurrentUser.UserID,
                            Global.CurrentUser.UManufacturers[0].ManufacturerID);

                    tdCharts.Visible = false;
                }
                else if (Global.CurrentUser.UserTypeID == (int)Entity.User.UserType.VendorCSM)
                {
                    lstPOProductRequisition =
                        POProductRequisitionManager.GetPOProductReqsByManufacturerID(
                            Convert.ToInt64(ViewState["Hospital"]),
                            Convert.ToInt64(ViewState["Department"]),
                            Global.CurrentUser.UManufacturers[0].ManufacturerID, Global.CurrentUser.UserID);

                    tdCharts.Visible = false;
                }

                DataTable dt = new DataTable();

                dt.Columns.Add(new DataColumn("Department", typeof (string)));
                dt.Columns.Add(new DataColumn("Modality", typeof (string)));
                dt.Columns.Add(new DataColumn("DateCreated", typeof (DateTime)));
                dt.Columns.Add(new DataColumn("DocumentNumber", typeof (string)));
                dt.Columns.Add(new DataColumn("Physician", typeof (string)));
                dt.Columns.Add(new DataColumn("Procedure", typeof (string)));
                dt.Columns.Add(new DataColumn("Vendor", typeof (string)));
                dt.Columns.Add(new DataColumn("Status", typeof (string)));
                dt.Columns.Add(new DataColumn("POProductRequisitionID", typeof (long)));
                dt.Columns.Add(new DataColumn("Completed", typeof (bool)));
                dt.Columns.Add(new DataColumn("ApprovalStatusID", typeof (int)));
                dt.Columns.Add(new DataColumn("PONumber", typeof (string)));
                dt.Columns.Add(new DataColumn("TotalValue", typeof (double)));
                dt.Columns.Add(new DataColumn("Hospital", typeof (string)));
                dt.Columns.Add(new DataColumn("UserTypeID", typeof(int)));
                dt.Columns.Add(new DataColumn("FirstApproverUserID", typeof(long)));
                dt.Columns.Add(new DataColumn("BuyerUserID", typeof(long)));
                dt.Columns.Add(new DataColumn("MRN", typeof(string)));
                dt.Columns.Add(new DataColumn("Capitation", typeof(string)));
                dt.Columns.Add(new DataColumn("Trial", typeof(string)));
                dt.Columns.Add(new DataColumn("Wasted", typeof(string)));
                dt.Columns.Add(new DataColumn("AlternateFirstApproverUserID", typeof(long)));
                dt.Columns.Add(new DataColumn("Capit", typeof(string)));

                foreach (POProductRequisition popr in lstPOProductRequisition)
                {
                    DataRow dr = dt.NewRow();
                    dr[0] = popr.POProdDepartment.DepartmentName;
                    dr[1] = popr.POProdModality.ModalityName;
                    dr[2] = popr.CreatedDateTime;
                    dr[3] = popr.DocumentNumber;
                    dr[4] = popr.POProdPhysician.LastName + ", " + popr.POProdPhysician.FirstName;
                    dr[5] = popr.POProdProcedure.ProcedureName;
                    dr[6] = popr.POProdVendor.LastName + ", " + popr.POProdVendor.FirstName;
                    if (popr.ApprovalStatusID == Convert.ToInt32(POProductRequisition.ApprovalStatus.Clarification))
                        dr[7] = "Routed for Clarification";
                    else if (popr.ApprovalStatusID == Convert.ToInt32(POProductRequisition.ApprovalStatus.PendingCSRReview))
                        dr[7] = "Routed for CSR Review";
                    else if (popr.ApprovalStatusID == Convert.ToInt32(POProductRequisition.ApprovalStatus.PendingUtilization))
                        dr[7] = "Routed for Utilization";
                    else if (!popr.Completed)
                    {
                        if (popr.ApprovalStatusID == Convert.ToInt32(POProductRequisition.ApprovalStatus.Returned))
                            dr[7] = "Draft (Returned)";
                        else 
                            dr[7] = popr.ApprovalStatusID == Convert.ToInt32(POProductRequisition.ApprovalStatus.Clarified) ? "Draft (Clarified)" : "Draft";
                    }
                    else
                    {
                        switch (popr.ApprovalStatusID)
                        {
                            case (int) POProductRequisition.ApprovalStatus.NotApproved:
                            case (int) POProductRequisition.ApprovalStatus.FirstLevelApproved:
                            case (int) POProductRequisition.ApprovalStatus.SecondLevelApproved:
                                dr[7] = "Waiting on Approval";
                                break;
                            case (int) POProductRequisition.ApprovalStatus.ApprovedWaitingForPO:
                                dr[7] = "Waiting for PO";
                                break;
                            case (int) POProductRequisition.ApprovalStatus.ApprovedWithPO:
                                dr[7] = "Complete";
                                break;
                            case (int) POProductRequisition.ApprovalStatus.Declined:
                                dr[7] = "Declined";
                                break;
                            case (int) POProductRequisition.ApprovalStatus.Clarification:
                                dr[7] = "Routed for Clarification";
                                break;
                            case (int)POProductRequisition.ApprovalStatus.ConfirmedUtilization:
                                dr[7] = "Waiting on Approval (Utilization Confirmed)";
                                break;
                            default:
                                dr[7] = "Draft";
                                break;
                        }
                    }

                    if (popr.Notes.Trim().Length > 0)
                        dr[7] += " <img src='./images/NoteIcon.png' title='" + popr.Notes + "'/>";
                    dr[8] = popr.POProductRequisitionID;
                    dr[9] = popr.Completed;
                    dr[10] = popr.ApprovalStatusID;
                    dr[11] = popr.PONumber;
                    dr[12] = popr.TotalValue;
                    dr[13] = popr.POProdHospital.HospitalName;
                    dr[14] = popr.PreparedByUserID.UserTypeID;
                    dr[15] = popr.POApprovalRouting.ARFirstApproverUser.UserID;
                    dr[16] = popr.POApprovalRouting.ARBuyerUser.UserID;
                    dr[17] = popr.PatientIdentifier;

                    if (popr.CapitationCharge > 0)
                        dr[18] = " <img src='./images/baseball_cap.gif' width='15px' height='15px' title='PO contains a capitation'/>";

                    if (popr.TrialProducts)
                        dr[19] = " <img src='./images/chemistry.png' width='15px' height='15px' title='PO contains trial products'/>";

                    if (popr.WastedProducts)
                        dr[20] = " <img src='./images/trash.png' width='15px' height='15px' title='PO contains wasted products'/>";

                    
                    if (popr.POApprovalRouting.AllAlternate && Global.CurrentUser.UserTypeID == (int)Entity.User.UserType.HospitalUser)
                        dr[21] = Global.CurrentUser.UserID;
                    else
                        dr[21] = popr.POApprovalRouting.ARAlternateFirstApproverUserID.UserID;
                    
                    //Demo of CAP catcher
                    if (Global.CurrentUser.UserID == 24 && popr.DocumentNumber == "DQPY0123327")
                    {
                        dr[22] = " <img src='./images/smallmoney.png' width='15px' height='15px' title='CAP Catcher Alert'/>";
                    }
                    //End Demo CAP Catcher

                    if (ViewState["po"] == null)
                        dt.Rows.Add(dr);
                    else if (ViewState["po"].ToString() == "p" && (!dr[7].ToString().Contains("Complete") && !dr[7].ToString().Contains("Declined")))
                        dt.Rows.Add(dr);
                    else if (ViewState["po"].ToString() == "i" && (dr[7].ToString().Contains("Complete")))
                        dt.Rows.Add(dr);
                    else if (ViewState["po"].ToString() == "d" && (dr[7].ToString().Contains("Declined")))
                        dt.Rows.Add(dr);
                }

                string strSort = dt.Columns[Convert.ToInt32(ViewState["SortCol"])].ColumnName + " ";
                strSort += Convert.ToString(ViewState["SortOrder"]);

                DataView dv = new DataView(dt);
                dv.Sort = strSort;

                ViewState["POCount"] = dv.Count;

                rptPOs.DataSource = dv;
                rptPOs.DataBind();

                if (ViewState["po"].ToString() == "p" && dv.Count > 0 && (Global.CurrentUser.UserTypeID == (int)Entity.User.UserType.HospitalUser))
                {
                    tdCharts.Visible = true;
                    RefreshChart();
                }
                else
                    tdCharts.Visible = false;
            }
        }

        protected void OnRptPOsItemCommand(object source, RepeaterCommandEventArgs e)
        {
            switch (e.CommandName)
            {
                case "Sort":
                    SortGrid(Convert.ToInt32(e.CommandArgument));
                    break;
                case "Edit":
                    {
                        Response.Redirect("POReqProducts.aspx?rID=" + e.CommandArgument);
                    }
                    break;
                case "View":
                    {
                        POProductRequisition poProductRequisition =
                            POProductRequisitionManager.GetPOProductRequisitionByID(
                                Convert.ToInt64(e.CommandArgument), Global.CurrentUser.UserID);

                        if (poProductRequisition.Completed && (
                            poProductRequisition.ApprovalStatusID == Convert.ToInt32(POProductRequisition.ApprovalStatus.NotApproved) ||
                            poProductRequisition.ApprovalStatusID == Convert.ToInt32(POProductRequisition.ApprovalStatus.ConfirmedUtilization)))
                        {
                            ApprovalRouting approvalRouting =
                                ApprovalRoutingManager.GetApproversByIDs(
                                    poProductRequisition.POProdHospital.HospitalID,
                                    poProductRequisition.POProdDepartment.DepartmentID,
                                    poProductRequisition.POProdModality.ModalityID,
                                    poProductRequisition.POProdVendor.UManufacturers[0].ManufacturerID);

                            /*if (approvalRouting.ARFirstApproverUser.UserID == Global.CurrentUser.UserID)
                            {
                                Response.Redirect("POReqProducts.aspx?rID=" + e.CommandArgument);
                            }
                            else*/
                                Response.Redirect("ViewPOProduct.aspx?rID=" + e.CommandArgument);
                        }

                        Response.Redirect("ViewPOProduct.aspx?rID=" + e.CommandArgument);
                    }
                    break;
                case "Delete":
                    {
                        POProductRequisitionManager.DeletePOProductRequisitionByID(Convert.ToInt64(e.CommandArgument));

                        RefreshPage(true);
                    }
                    break;
                case "Archive":
                    {
                        OnArchive();
                    }
                    break;
                default:
                    RefreshPage(true);
                    break;
            }
        }

        private void SortGrid(int iNewSortCol)
        {
            //Get current sort column
            int iOldSortCol = Convert.ToInt32(ViewState["SortCol"]);
            //Get current sort order
            String strOldSortOrder = Convert.ToString(ViewState["SortOrder"]);
            String strNewSortOrder = "ASC"; //ascending, unless the column clicked is the same as the one currently sorted

            if (iNewSortCol == iOldSortCol)
            {
                strNewSortOrder = strOldSortOrder == "ASC" ? "DESC" : "ASC";
            }

            ViewState["SortCol"] = iNewSortCol;
            ViewState["SortOrder"] = strNewSortOrder;

            //Refresh controls
            RefreshPage(true);
        }

        protected void OnRptPOsItemDataBound(object sender, RepeaterItemEventArgs e)
        {
            if (e.Item.ItemType == ListItemType.AlternatingItem || e.Item.ItemType == ListItemType.Item)
            {
                e.Item.FindControl("tdArchive").Visible = ViewState["po"].ToString() != "p";
                HiddenField hfApprovalStatusID = (HiddenField)e.Item.FindControl("hfApprovalStatusID");

                if(Convert.ToBoolean(((HiddenField)e.Item.FindControl("hfCompleted")).Value))
                {
                    e.Item.FindControl("lbEditPO").Visible = false;

                    if (Convert.ToInt32(hfApprovalStatusID.Value) == (int)POProductRequisition.ApprovalStatus.ApprovedWithPO)
                    {
                        e.Item.FindControl("lbDeletePO").Visible = false;
                    }

                    if (Convert.ToInt32(hfApprovalStatusID.Value) == (int)POProductRequisition.ApprovalStatus.ApprovedWithPO ||
                        Convert.ToInt32(hfApprovalStatusID.Value) == (int)POProductRequisition.ApprovalStatus.Declined)
                    {
                        e.Item.FindControl("cbArchive").Visible = true;
                    }
                }

                e.Item.FindControl("tdPONumber").Visible = ViewState["po"].ToString() == "i";

                HiddenField hfFAUserID = (HiddenField) e.Item.FindControl("hfFAUserID");
                HiddenField hfAlternateUserID = (HiddenField)e.Item.FindControl("hfAlternateUserID");
                HiddenField hfBUserID = (HiddenField)e.Item.FindControl("hfBUserID");
                HtmlTableCell htc = (HtmlTableCell)e.Item.FindControl("tdStatus");

                bool bShowEdit = false;

                if (Convert.ToInt64(hfFAUserID.Value) == Global.CurrentUser.UserID || 
                    ((hfAlternateUserID.Value.Length > 0) && Convert.ToInt64(hfAlternateUserID.Value) == Global.CurrentUser.UserID))
                    bShowEdit = true;    

                if (htc.InnerText.Contains("Clarified"))
                    ((HtmlTableCell) e.Item.FindControl("tdStatus")).Style.Add("color", "DarkTurquoise");
                else if (htc.InnerText.Contains("CSR Review"))
                {
                    ((HtmlTableCell) e.Item.FindControl("tdStatus")).Style.Add("color", "MediumBlue");

                    if (Global.CurrentUser.UserTypeID != (int) Entity.User.UserType.VendorCSM)
                    {
                        e.Item.FindControl("lbEditPO").Visible = false;
                    }
                }
                else if (htc.InnerText.Contains("Confirmed"))
                {
                    e.Item.FindControl("lbEditPO").Visible = bShowEdit;

                    ((HtmlTableCell)e.Item.FindControl("tdStatus")).Style.Add("color", "DodgerBlue");
                }
                else if (htc.InnerText.Contains("Returned"))
                    ((HtmlTableCell)e.Item.FindControl("tdStatus")).Style.Add("color", "DarkGoldenrod");
                else if (htc.InnerText.Contains("Draft"))
                    ((HtmlTableCell)e.Item.FindControl("tdStatus")).Style.Add("color", "Sienna");
                else if (htc.InnerText.Contains("Waiting for PO"))
                {
                    e.Item.FindControl("lbEditPO").Visible = Convert.ToInt64(hfBUserID.Value) == Global.CurrentUser.UserID;

                    ((HtmlTableCell)e.Item.FindControl("tdStatus")).Style.Add("color", "DarkOrange");
                }
                else if (htc.InnerText.Contains("Waiting on Approval"))
                {
                    e.Item.FindControl("lbEditPO").Visible = bShowEdit;
                    ((HtmlTableCell)e.Item.FindControl("tdStatus")).Style.Add("color", "DarkViolet");
                }
                else if (htc.InnerText.Contains("Complete"))
                    ((HtmlTableCell)e.Item.FindControl("tdStatus")).Style.Add("color", "DarkGreen");
                else if (htc.InnerText.Contains("Declined"))
                    ((HtmlTableCell)e.Item.FindControl("tdStatus")).Style.Add("color", "DarkRed");
                else if (htc.InnerText.Contains("Routed for Clarification"))
                {
                    ((HtmlTableCell)e.Item.FindControl("tdStatus")).Style.Add("color", "DarkBlue");
                    e.Item.FindControl("lbEditPO").Visible = false;
                }
                else if (htc.InnerText.Contains("Routed for Utilization"))
                {
                    ((HtmlTableCell)e.Item.FindControl("tdStatus")).Style.Add("color", "Blue");
                    e.Item.FindControl("lbEditPO").Visible = false;
                }

                if (Convert.ToInt32(((HiddenField)e.Item.FindControl("hfUserTypeID")).Value) == (int)Entity.User.UserType.VendorUser ||
                    Convert.ToInt32(((HiddenField)e.Item.FindControl("hfUserTypeID")).Value) == (int)Entity.User.UserType.VendorCSM)
                {
                    ((HtmlTableCell)e.Item.FindControl("tdVendor")).Style.Add("color", "Red");
                    ((HtmlTableCell)e.Item.FindControl("tdVendor")).Style.Add("font-weight", "Bold");
                }

                long lID = Convert.ToInt64(((LinkButton)e.Item.FindControl("lbViewPO")).CommandArgument);
                ((HtmlTableRow)e.Item.FindControl("trPOs")).Style.Add("cursor", "hand");

                e.Item.FindControl("lbDeletePO").Visible = false;
            }
            else if(e.Item.ItemType == ListItemType.Header)
            {
                e.Item.FindControl("tdHeaderPONmber").Visible = ViewState["po"].ToString() == "i";
                e.Item.FindControl("tdHeaderArchive").Visible = ViewState["po"].ToString() != "p";
            }
            else if (e.Item.ItemType == ListItemType.Footer)
            {
                e.Item.FindControl("lbArchive").Visible = Convert.ToInt64(ViewState["POCount"]) > 0 &&
                                                          ViewState["po"].ToString() != "p";
            }
        }

        private void RefreshChart()
        {
            int iCount = 0;
            List<Graphic> lstGraphics = GraphicManager.GetChartsByUserIDPageID(Global.CurrentUser.UserID, 2);
            foreach (Graphic g in lstGraphics)
            {
                if (g.GraphicID == 1 && Convert.ToInt64(ViewState["Hospital"]) > 0 && Convert.ToInt64(ViewState["Department"]) > 0)
                {
                    DataTable dt =
                        POProductRequisitionManager.GetPOProductsReqsGroupByModality(Global.CurrentUser.UserID,
                                                                                     Convert.ToInt64(ViewState["Hospital"]),
                                                                                     Convert.ToInt64(ViewState["Department"]));

                    if (dt.Rows.Count > 0)
                    {
                        Color[] c =
                            {
                                Color.Sienna,
                                Color.OliveDrab,
                                Color.Peru,
                                Color.Maroon,
                                Color.YellowGreen,
                                Color.Crimson,
                                Color.CornflowerBlue,
                                Color.Chocolate,
                                Color.Olive,
                                Color.DarkKhaki,
                                Color.PaleGoldenrod,
                                Color.Tan,
                                Color.Khaki,
                                Color.DarkGoldenrod,
                            };

                        StringBuilder xmlData = new StringBuilder();
                        StringBuilder xmlDataModal = new StringBuilder();

                        xmlData.Append(
                            "<chart palette='3' captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='YTD PO Activity - Modality' showValues='0' bgcolor='#F0F0F0' showBorder='0' formatNumberScale='0' enableRotation='1' showLabels='0' baseFont='Verdana' baseFontSize='10' baseFontColor='black' enableSmartLabels='1' pieYScale='60'>");
                        xmlDataModal.Append(
                            "<chart   captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='YTD PO Activity - Modality' bgcolor='#F0F0F0' showBorder='0' formatNumberScale='0' enableRotation='1' showLabels='1' baseFont='Verdana' baseFontSize='12' baseFontColor='black' startingAngle='270' pieYScale='60'>");

                        int i = 0;

                        foreach (DataRow dr in dt.Rows)
                        {
                            xmlData.AppendFormat(
                                "<set color='" + string.Format("{0:X2}{1:X2}{2:X2}", c[i].R, c[i].G, c[i].B) +
                                "' label='{0}' value='{1}' />", dr["Modality"], dr["POCount"]);
                            xmlDataModal.AppendFormat(
                                "<set color='" + string.Format("{0:X2}{1:X2}{2:X2}", c[i].R, c[i].G, c[i].B) +
                                "' label='{0}' value='{1}' />", dr["Modality"], dr["POCount"]);


                            i++;

                            if (i > 12)
                                i = 0;
                        }

                        xmlDataModal.AppendFormat(
                            "<styles><definition><style name='myCaptionFont' type='font' size='16' bold='1' underline='1'/></definition>");
                        xmlDataModal.AppendFormat(
                            "<application><apply toObject='Caption' styles='myCaptionFont' /></application> </styles>");

                        xmlData.Append("</chart>");
                        xmlDataModal.Append("</chart>");

                        if (iCount == 0)
                        {
                            lChart1.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart4.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 1)
                        {
                            lChart2.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart5.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 2)
                        {
                            lChart3.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart6.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                    }
                }
                else if (g.GraphicID == 2 && Convert.ToInt64(ViewState["Hospital"]) > 0 && Convert.ToInt64(ViewState["Department"]) > 0)
                {
                    DataTable dt2 =
                        POProductRequisitionManager.GetPOProductsReqsGroupByManufacturer(Global.CurrentUser.UserID,
                                                                                         Convert.ToInt64(ViewState["Hospital"]),
                                                                                         Convert.ToInt64(ViewState["Department"]));

                    if (dt2.Rows.Count > 0)
                    {
                        StringBuilder xmlData = new StringBuilder();
                        StringBuilder xmlDataModal = new StringBuilder();

                        xmlData.Append(
                            "<chart palette='5' captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='YTD PO Activity - Vendor' showValues='0' showYAxisValues='0' bgcolor='#F0F0F0' pieSliceDepth='30' showBorder='0' formatNumberScale='0' enableRotation='1' showLabels='0' baseFont='Verdana' baseFontSize='10' baseFontColor='black'>");
                        xmlDataModal.Append(
                            "<chart   palette='5' captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='YTD PO Activity - Vendor' bgcolor='#F0F0F0' pieSliceDepth='30' showBorder='0' formatNumberScale='0' enableRotation='1' showLabels='1' baseFont='Verdana' baseFontSize='12' baseFontColor='black'>");

                        foreach (DataRow dr in dt2.Rows)
                        {
                            xmlData.AppendFormat("<set label='{0}' value='{1}' />", dr["ManufacturerName"],
                                                 dr["POCount"]);
                            xmlDataModal.AppendFormat("<set label='{0}' value='{1}' />", dr["ManufacturerName"],
                                                      dr["POCount"]);
                        }

                        xmlDataModal.AppendFormat(
                            "<styles><definition><style name='myCaptionFont' type='font' size='16' bold='1' underline='1'/></definition>");
                        xmlDataModal.AppendFormat(
                            "<application><apply toObject='Caption' styles='myCaptionFont' /></application> </styles>");

                        xmlData.Append("</chart>");
                        xmlDataModal.Append("</chart>");

                        if (iCount == 0)
                        {
                            lChart1.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart4.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 1)
                        {
                            lChart2.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart5.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 2)
                        {
                            lChart3.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart6.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                    }
                }
                else if (g.GraphicID == 3 && Convert.ToInt64(ViewState["Hospital"]) > 0 && Convert.ToInt64(ViewState["Department"]) > 0)
                {
                    DataTable dt3 =
                        POProductRequisitionManager.GetPOProductsReqsGroupByManufacturerCurrentMonth(
                            Global.CurrentUser.UserID,
                            Convert.ToInt64(ViewState["Hospital"]),
                            Convert.ToInt64(ViewState["Department"]));

                    if (dt3.Rows.Count > 0)
                    {
                        Color[] c =
                            {
                                Color.DarkSeaGreen,
                                Color.DarkSlateBlue,
                                Color.DarkGoldenrod,
                                Color.DarkSalmon,
                                Color.DarkTurquoise,
                                Color.DarkViolet,
                                Color.DarkGray,
                                Color.DarkRed,
                                Color.DarkGreen,
                                Color.DarkSlateGray,
                                Color.DarkOrange,
                                Color.DarkMagenta,
                                Color.DarkBlue,
                                Color.DeepSkyBlue
                            };

                        StringBuilder xmlData = new StringBuilder();
                        StringBuilder xmlDataModal = new StringBuilder();

                        xmlData.Append(
                            "<chart palette='4' captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='MTD PO Activity - Vendor' showValues='0' bgcolor='#B0B0B0' showBorder='0' formatNumberScale='0' enableRotation='1' showLabels='0' baseFont='Verdana' baseFontSize='10' baseFontColor='black' enableSmartLabels='1' pieYScale='60'>");
                        xmlDataModal.Append(
                            "<chart   captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='MTD PO Activity - Vendor' bgcolor='#F0F0F0' showBorder='0' formatNumberScale='0' enableRotation='1' showLabels='1' baseFont='Verdana' baseFontSize='12' baseFontColor='black' startingAngle='270' pieYScale='60'>");

                        int i = 0;

                        foreach (DataRow dr in dt3.Rows)
                        {
                            xmlData.AppendFormat(
                                "<set color='" + string.Format("{0:X2}{1:X2}{2:X2}", c[i].R, c[i].G, c[i].B) +
                                "' label='{0}' value='{1}' />", dr["ManufacturerName"], dr["POCount"]);
                            xmlDataModal.AppendFormat(
                                "<set color='" + string.Format("{0:X2}{1:X2}{2:X2}", c[i].R, c[i].G, c[i].B) +
                                "' label='{0}' value='{1}' />", dr["ManufacturerName"], dr["POCount"]);

                            i++;

                            if (i > 12)
                                i = 0;
                        }

                        xmlDataModal.AppendFormat(
                            "<styles><definition><style name='myCaptionFont' type='font' size='16' bold='1' underline='1'/></definition>");
                        xmlDataModal.AppendFormat(
                            "<application><apply toObject='Caption' styles='myCaptionFont' /></application> </styles>");

                        xmlData.Append("</chart>");
                        xmlDataModal.Append("</chart>");

                        if (iCount == 0)
                        {
                            lChart1.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart4.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 1)
                        {
                            lChart2.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart5.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 2)
                        {
                            lChart3.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart6.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                    }
                }
                else if (g.GraphicID == 10 && Convert.ToInt64(ViewState["Hospital"]) > 0 && Convert.ToInt64(ViewState["Department"]) > 0)
                {
                    DataTable dt =
                        POProductRequisitionManager.GetPOProductsReqsAvgValueYTDByUserID(
                            Global.CurrentUser.UserID,
                            Convert.ToInt64(ViewState["Hospital"]),
                            Convert.ToInt64(ViewState["Department"]));

                    if (dt.Rows.Count > 0)
                    {
                        Color[] c =
                            {
                                Color.Sienna,
                                Color.OliveDrab,
                                Color.Peru,
                                Color.Maroon,
                                Color.YellowGreen,
                                Color.Crimson,
                                Color.CornflowerBlue,
                                Color.Chocolate,
                                Color.Olive,
                                Color.DarkKhaki,
                                Color.PaleGoldenrod,
                                Color.Tan,
                                Color.Khaki,
                                Color.DarkGoldenrod,
                            };

                        StringBuilder xmlData = new StringBuilder();
                        StringBuilder xmlDataModal = new StringBuilder();

                        xmlData.Append(
                            "<chart palette='3' captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='Avg PO Value - YTD' bgcolor='#F0F0F0' showValues='0' numberPrefix='$' showBorder='0' formatNumberScale='0' enableRotation='1' showLabels='0' baseFont='Verdana' baseFontSize='10' baseFontColor='black' enableSmartLabels='1' pieYScale='60'>");
                        xmlDataModal.Append(
                            "<chart   captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='Avg PO Value - YTD' bgcolor='#F0F0F0' showBorder='0' numberPrefix='$' formatNumberScale='0' enableRotation='1' showLabels='1' baseFont='Verdana' baseFontSize='12' baseFontColor='black' startingAngle='270' pieYScale='60'>");

                        int i = 0;

                        foreach (DataRow dr in dt.Rows)
                        {
                            xmlData.AppendFormat(
                                "<set color='" + string.Format("{0:X2}{1:X2}{2:X2}", c[i].R, c[i].G, c[i].B) +
                                "' label='{0}' value='{1}' />", dr["ManufacturerName"], dr["TotalValue"]);
                            xmlDataModal.AppendFormat(
                                "<set color='" + string.Format("{0:X2}{1:X2}{2:X2}", c[i].R, c[i].G, c[i].B) +
                                "' label='{0}' value='{1}' />", dr["ManufacturerName"], dr["TotalValue"]);


                            i++;

                            if (i > 12)
                                i = 0;
                        }

                        xmlDataModal.AppendFormat(
                            "<styles><definition><style name='myCaptionFont' type='font' size='16' bold='1' underline='1'/></definition>");
                        xmlDataModal.AppendFormat(
                            "<application><apply toObject='Caption' styles='myCaptionFont' /></application> </styles>");

                        xmlData.Append("</chart>");
                        xmlDataModal.Append("</chart>");

                        if (iCount == 0)
                        {
                            lChart1.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart4.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 1)
                        {
                            lChart2.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart5.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 2)
                        {
                            lChart3.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart6.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                    }
                }
                else if (g.GraphicID == 11 && Convert.ToInt64(ViewState["Hospital"]) > 0 && Convert.ToInt64(ViewState["Department"]) > 0)
                {
                    DataTable dt2 =
                        POProductRequisitionManager.GetPOProductsReqsAvgValueMTDByUserID(
                            Global.CurrentUser.UserID,
                            Convert.ToInt64(ViewState["Hospital"]),
                            Convert.ToInt64(ViewState["Department"]));

                    if (dt2.Rows.Count > 0)
                    {
                        StringBuilder xmlData = new StringBuilder();
                        StringBuilder xmlDataModal = new StringBuilder();

                        xmlData.Append(
                            "<chart palette='5' captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='Avg PO Value - MTD' bgcolor='#F0F0F0' showYAxisValues='0' showValues='0' numberPrefix='$' pieSliceDepth='30' showBorder='0' formatNumberScale='0' enableRotation='1' showLabels='0' baseFont='Verdana' baseFontSize='10' baseFontColor='black'>");
                        xmlDataModal.Append(
                            "<chart   palette='5' captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='Avg PO Value - MTD' bgcolor='#F0F0F0' numberPrefix='$' pieSliceDepth='30' showBorder='0' formatNumberScale='0' enableRotation='1' showLabels='1' baseFont='Verdana' baseFontSize='12' baseFontColor='black'>");

                        foreach (DataRow dr in dt2.Rows)
                        {
                            xmlData.AppendFormat("<set label='{0}' value='{1}' />", dr["ManufacturerName"],
                                                 dr["TotalValue"]);
                            xmlDataModal.AppendFormat("<set label='{0}' value='{1}' />", dr["ManufacturerName"],
                                                      dr["TotalValue"]);
                        }

                        xmlDataModal.AppendFormat(
                            "<styles><definition><style name='myCaptionFont' type='font' size='16' bold='1' underline='1'/></definition>");
                        xmlDataModal.AppendFormat(
                            "<application><apply toObject='Caption' styles='myCaptionFont' /></application> </styles>");

                        xmlData.Append("</chart>");
                        xmlDataModal.Append("</chart>");

                        if (iCount == 0)
                        {
                            lChart1.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart4.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 1)
                        {
                            lChart2.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart5.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 2)
                        {
                            lChart3.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart6.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                    }
                }
                else if (g.GraphicID == 12 && Convert.ToInt64(ViewState["Hospital"]) > 0 && Convert.ToInt64(ViewState["Department"]) > 0)
                {
                    DataTable dt12 =
                        POProductRequisitionManager.GetPOProductsReqsAvgValueThisWeekByUserID(
                            Global.CurrentUser.UserID,
                            Convert.ToInt64(ViewState["Hospital"]),
                            Convert.ToInt64(ViewState["Department"]));

                    if (dt12.Rows.Count > 0)
                    {
                        Color[] c =
                            {
                                Color.DarkSeaGreen,
                                Color.DarkSlateBlue,
                                Color.DarkGoldenrod,
                                Color.DarkSalmon,
                                Color.DarkTurquoise,
                                Color.DarkViolet,
                                Color.DarkGray,
                                Color.DarkRed,
                                Color.DarkGreen,
                                Color.DarkSlateGray,
                                Color.DarkOrange,
                                Color.DarkMagenta,
                                Color.DarkBlue,
                                Color.DeepSkyBlue
                            };

                        StringBuilder xmlData = new StringBuilder();
                        StringBuilder xmlDataModal = new StringBuilder();

                        xmlData.Append(
                            "<chart palette='4' captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='Avg PO Value - This Week' bgcolor='#B0B0B0' showValues='0' numberPrefix='$' showBorder='0' formatNumberScale='0' enableRotation='1' showLabels='0' baseFont='Verdana' baseFontSize='10' baseFontColor='black' enableSmartLabels='1' pieYScale='60'>");
                        xmlDataModal.Append(
                            "<chart   captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='Avg PO Value - This Week' bgcolor='#B0B0B0' showBorder='0' numberPrefix='$' formatNumberScale='0' enableRotation='1' showLabels='1' baseFont='Verdana' baseFontSize='12' baseFontColor='black' startingAngle='270' pieYScale='60'>");

                        int i = 0;

                        foreach (DataRow dr in dt12.Rows)
                        {
                            xmlData.AppendFormat(
                                "<set color='" + string.Format("{0:X2}{1:X2}{2:X2}", c[i].R, c[i].G, c[i].B) +
                                "' label='{0}' value='{1}' />", dr["ManufacturerName"], dr["TotalValue"]);
                            xmlDataModal.AppendFormat(
                                "<set color='" + string.Format("{0:X2}{1:X2}{2:X2}", c[i].R, c[i].G, c[i].B) +
                                "' label='{0}' value='{1}' />", dr["ManufacturerName"], dr["TotalValue"]);

                            i++;

                            if (i > 12)
                                i = 0;
                        }

                        xmlDataModal.AppendFormat(
                            "<styles><definition><style name='myCaptionFont' type='font' size='16' bold='1' underline='1'/></definition>");
                        xmlDataModal.AppendFormat(
                            "<application><apply toObject='Caption' styles='myCaptionFont' /></application> </styles>");

                        xmlData.Append("</chart>");
                        xmlDataModal.Append("</chart>");

                        if (iCount == 0)
                        {
                            lChart1.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart4.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 1)
                        {
                            lChart2.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart5.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 2)
                        {
                            lChart3.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart6.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                    }
                }
                else if (g.GraphicID == 13 && Convert.ToInt64(ViewState["Hospital"]) > 0 && Convert.ToInt64(ViewState["Department"]) > 0)
                {
                    List<POProductRequisition> lstPOProductRequisition =
                        POProductRequisitionManager.GetPOProductsReqsCurrentActivity(Global.CurrentUser.UserID,
                                                                                     Convert.ToInt64(ViewState["Hospital"]),
                                                                                     Convert.ToInt64(ViewState["Department"]));

                    long lPending = 0;
                    long lSubmitted = 0;
                    long lApproved = 0;

                    DataTable dt7 = new DataTable();

                    dt7.Columns.Add(new DataColumn("POCount", typeof (long)));
                    dt7.Columns.Add(new DataColumn("POType", typeof (string)));

                    if (lstPOProductRequisition.Count > 0)
                    {
                        foreach (POProductRequisition popr in lstPOProductRequisition)
                        {
                            if (popr.Completed)
                            {
                                if (popr.ApprovalStatusID ==
                                    (int) POProductRequisition.ApprovalStatus.ApprovedWaitingForPO)
                                    lApproved++;
                                else
                                    lSubmitted++;
                            }
                            else
                                lPending++;
                        }

                        DataRow dr = dt7.NewRow();
                        dr[0] = lPending;
                        dr[1] = "Pending";
                        dt7.Rows.Add(dr);

                        dr = dt7.NewRow();
                        dr[0] = lSubmitted;
                        dr[1] = "Submitted";
                        dt7.Rows.Add(dr);

                        dr = dt7.NewRow();
                        dr[0] = lApproved;
                        dr[1] = "Approved";
                        dt7.Rows.Add(dr);

                        StringBuilder xmlData = new StringBuilder();
                        StringBuilder xmlDataModal = new StringBuilder();

                        xmlData.Append(
                            "<chart captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='Current Activity' bgcolor='#F0F0F0' showBorder='0' showYAxisValues='0'  showValues='0' formatNumberScale='0' showLabels='0' baseFont='Verdana' baseFontSize='10' baseFontColor='black' enableSmartLabels='1'>");

                        xmlDataModal.Append(
                            "<chart   captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='Current Activity' bgcolor='#F0F0F0' showBorder='0' formatNumberScale='0' showLabels='0' baseFont='Verdana' baseFontSize='10' baseFontColor='black' enableSmartLabels='1'>");

                        foreach (DataRow dr1 in dt7.Rows)
                        {
                            xmlData.AppendFormat("<set label='{0}' value='{1}' />", dr1["POType"], dr1["POCount"]);

                            xmlDataModal.AppendFormat("<set label='{0}' value='{1}' />", dr1["POType"], dr1["POCount"]);
                        }

                        xmlDataModal.AppendFormat(
                            "<styles><definition><style name='myCaptionFont' type='font' size='16' bold='1' underline='1'/></definition>");
                        xmlDataModal.AppendFormat(
                            "<application><apply toObject='Caption' styles='myCaptionFont' /></application> </styles>");

                        xmlData.Append("</chart>");
                        xmlDataModal.Append("</chart>");

                        if (iCount == 0)
                        {
                            lChart1.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart4.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 1)
                        {
                            lChart2.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart5.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 2)
                        {
                            lChart3.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart6.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                    }
                }
                else if (g.GraphicID == 14 && Convert.ToInt64(ViewState["Hospital"]) > 0 && Convert.ToInt64(ViewState["Department"]) > 0)
                {
                    DataTable dt12 =
                        POProductRequisitionManager.GetPOProductsReqsRequestSource(Global.CurrentUser.UserID,
                                                                                   Convert.ToInt64(ViewState["Hospital"]),
                                                                                   Convert.ToInt64(ViewState["Department"]));

                    if (dt12.Rows.Count > 0)
                    {
                        Color[] c =
                            {
                                Color.Sienna,
                                Color.OliveDrab,
                                Color.Peru,
                                Color.Maroon,
                                Color.YellowGreen,
                                Color.Crimson,
                                Color.CornflowerBlue,
                                Color.Chocolate,
                                Color.Olive,
                                Color.DarkKhaki,
                                Color.PaleGoldenrod,
                                Color.Tan,
                                Color.Khaki,
                                Color.DarkGoldenrod,
                            };

                        StringBuilder xmlData = new StringBuilder();
                        StringBuilder xmlDataModal = new StringBuilder();

                        xmlData.Append(
                            "<chart captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='PO Request Source' bgcolor='#F0F0F0' showBorder='0' showValues='0' formatNumberScale='0' enableRotation='1' showLabels='0' baseFont='Verdana' baseFontSize='10' baseFontColor='black' enableSmartLabels='1' pieYScale='60' enableSmartLabels='1' startingAngle='70'>");
                        xmlDataModal.Append(
                            "<chart   captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='PO Request Source' bgcolor='#F0F0F0' showBorder='0' formatNumberScale='0' enableRotation='1' showLabels='0' baseFont='Verdana' baseFontSize='10' baseFontColor='black' enableSmartLabels='1' pieYScale='60' enableSmartLabels='1' startingAngle='70'>");

                        int i = 0;

                        foreach (DataRow dr in dt12.Rows)
                        {
                            xmlData.AppendFormat(
                                "<set color='" + string.Format("{0:X2}{1:X2}{2:X2}", c[i].R, c[i].G, c[i].B) +
                                "' label='{0}' value='{1}' />", dr["RequestSource"], dr["POCount"]);
                            xmlDataModal.AppendFormat(
                                "<set color='" + string.Format("{0:X2}{1:X2}{2:X2}", c[i].R, c[i].G, c[i].B) +
                                "' label='{0}' value='{1}' />", dr["RequestSource"], dr["POCount"]);

                            i++;

                            if (i > 12)
                                i = 0;
                        }

                        xmlDataModal.AppendFormat(
                            "<styles><definition><style name='myCaptionFont' type='font' size='16' bold='1' underline='1'/></definition>");
                        xmlDataModal.AppendFormat(
                            "<application><apply toObject='Caption' styles='myCaptionFont' /></application> </styles>");

                        xmlData.Append("</chart>");
                        xmlDataModal.Append("</chart>");

                        if (iCount == 0)
                        {
                            lChart1.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart4.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 1)
                        {
                            lChart2.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart5.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 2)
                        {
                            lChart3.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart6.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                    }
                }
                else if (g.GraphicID == 15 && Convert.ToInt64(ViewState["Hospital"]) > 0 && Convert.ToInt64(ViewState["Department"]) > 0)
                {
                    DataTable dt12 =
                        POProductRequisitionManager.GetPOProductsReqsProcedureActivity(Global.CurrentUser.UserID,
                                                                                       Convert.ToInt64(ViewState["Hospital"]),
                                                                                       Convert.ToInt64(ViewState["Department"]));

                    if (dt12.Rows.Count > 0)
                    {
                        Color[] c =
                            {
                                Color.DarkSeaGreen,
                                Color.DarkSlateBlue,
                                Color.DarkGoldenrod,
                                Color.DarkSalmon,
                                Color.DarkTurquoise,
                                Color.DarkViolet,
                                Color.DarkGray,
                                Color.DarkRed,
                                Color.DarkGreen,
                                Color.DarkSlateGray,
                                Color.DarkOrange,
                                Color.DarkMagenta,
                                Color.DarkBlue,
                                Color.DeepSkyBlue,
                                Color.DarkViolet,
                                Color.DarkSeaGreen,
                                Color.DarkTurquoise,
                                Color.DarkGray,
                                Color.Cyan,
                                Color.Sienna,
                                Color.OliveDrab,
                                Color.Peru,
                                Color.Maroon,
                                Color.YellowGreen,
                                Color.Crimson,
                                Color.CornflowerBlue,
                                Color.Chocolate,
                                Color.Olive,
                                Color.DarkKhaki,
                                Color.PaleGoldenrod,
                                Color.Tan,
                                Color.Khaki
                            };

                        StringBuilder xmlData = new StringBuilder();
                        StringBuilder xmlDataModal = new StringBuilder();

                        xmlData.Append(
                            "<chart captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='Procedure Activity' bgcolor='#E0E0E0' showBorder='0' showValues='0' formatNumberScale='0' enableRotation='1' showLabels='0' baseFont='Verdana' baseFontSize='10' baseFontColor='black' enableSmartLabels='1' pieYScale='60'>");
                        xmlDataModal.Append(
                            "<chart   captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='Procedure Activity' bgcolor='#E0E0E0' showBorder='0' formatNumberScale='0' enableRotation='1' showLabels='0' baseFont='Verdana' baseFontSize='10' baseFontColor='black' enableSmartLabels='1' pieYScale='60'>");

                        int i = 0;

                        foreach (DataRow dr in dt12.Rows)
                        {
                            xmlData.AppendFormat(
                                "<set color='" + string.Format("{0:X2}{1:X2}{2:X2}", c[i].R, c[i].G, c[i].B) +
                                "' label='{0}' value='{1}' />", dr["ProcedureName"], dr["POCount"]);
                            xmlDataModal.AppendFormat(
                                "<set color='" + string.Format("{0:X2}{1:X2}{2:X2}", c[i].R, c[i].G, c[i].B) +
                                "' label='{0}' value='{1}' />", dr["ProcedureName"], dr["POCount"]);

                            i++;

                            if (i > 12)
                                i = 0;
                        }

                        xmlDataModal.AppendFormat(
                            "<styles><definition><style name='myCaptionFont' type='font' size='16' bold='1' underline='1'/></definition>");
                        xmlDataModal.AppendFormat(
                            "<application><apply toObject='Caption' styles='myCaptionFont' /></application> </styles>");

                        xmlData.Append("</chart>");
                        xmlDataModal.Append("</chart>");

                        if (iCount == 0)
                        {
                            lChart1.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart4.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 1)
                        {
                            lChart2.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart5.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 2)
                        {
                            lChart3.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart6.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                    }
                }
                else if (g.GraphicID == 16 && Convert.ToInt64(ViewState["Hospital"]) > 0 && Convert.ToInt64(ViewState["Department"]) > 0)
                {
                    DataTable dt10 =
                        POProductRequisitionManager.GetPOProductsReqsGroupByModalityMTD(Global.CurrentUser.UserID,
                                                                                        Convert.ToInt64(ViewState["Hospital"]),
                                                                                        Convert.ToInt64(ViewState["Department"]));

                    if (dt10.Rows.Count > 0)
                    {
                        Color[] c =
                            {
                                Color.DarkSeaGreen,
                                Color.DarkSlateBlue,
                                Color.DarkGoldenrod,
                                Color.DarkSalmon,
                                Color.DarkTurquoise,
                                Color.DarkViolet,
                                Color.DarkGray,
                                Color.DarkRed,
                                Color.DarkGreen,
                                Color.DarkSlateGray,
                                Color.DarkOrange,
                                Color.DarkMagenta,
                                Color.DarkBlue,
                                Color.DeepSkyBlue
                            };

                        StringBuilder xmlData = new StringBuilder();
                        StringBuilder xmlDataModal = new StringBuilder();

                        xmlData.Append(
                            "<chart palette='3' captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='MTD PO Activity - Modality' bgcolor='#E0E0E0' showValues='0' showBorder='0' formatNumberScale='0' enableRotation='1' showLabels='0' baseFont='Verdana' baseFontSize='10' baseFontColor='black' enableSmartLabels='1' pieYScale='60'>");

                        xmlDataModal.Append(
                            "<chart   palette='3' captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='MTD PO Activity - Modality' bgcolor='#E0E0E0' showBorder='0' formatNumberScale='0' enableRotation='1' showLabels='0' baseFont='Verdana' baseFontSize='10' baseFontColor='black' enableSmartLabels='1' pieYScale='60'>");

                        int i = 0;

                        foreach (DataRow dr in dt10.Rows)
                        {
                            xmlData.AppendFormat(
                                "<set color='" + string.Format("{0:X2}{1:X2}{2:X2}", c[i].R, c[i].G, c[i].B) +
                                "' label='{0}' value='{1}' />", dr["Modality"], dr["POCount"]);

                            xmlDataModal.AppendFormat(
                                "<set color='" + string.Format("{0:X2}{1:X2}{2:X2}", c[i].R, c[i].G, c[i].B) +
                                "' label='{0}' value='{1}' />", dr["Modality"], dr["POCount"]);

                            i++;

                            if (i > 12)
                                i = 0;
                        }

                        xmlDataModal.AppendFormat(
                            "<styles><definition><style name='myCaptionFont' type='font' size='16' bold='1' underline='1'/></definition>");
                        xmlDataModal.AppendFormat(
                            "<application><apply toObject='Caption' styles='myCaptionFont' /></application> </styles>");

                        xmlData.Append("</chart>");
                        xmlDataModal.Append("</chart>");

                        if (iCount == 0)
                        {
                            lChart1.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart4.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 1)
                        {
                            lChart2.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart5.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 2)
                        {
                            lChart3.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart6.Text =
                                FusionCharts.RenderChart("./FusionCharts/Doughnut2D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                    }
                }
                else if (g.GraphicID == 17 && Convert.ToInt64(ViewState["Hospital"]) > 0 && Convert.ToInt64(ViewState["Department"]) > 0)
                {
                    DataTable dt11 =
                        POProductRequisitionManager.GetPOProductsReqsGroupByModalityToday(Global.CurrentUser.UserID,
                                                                                          Convert.ToInt64(ViewState["Hospital"]),
                                                                                          Convert.ToInt64(ViewState["Department"]));

                    if (dt11.Rows.Count > 0)
                    {
                        StringBuilder xmlData = new StringBuilder();
                        StringBuilder xmlDataModal = new StringBuilder();

                        xmlData.Append(
                            "<chart palette='5' captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='Todays PO Activity - Modality' bgcolor='#F0F0F0' showYAxisValues='0' showValues='0' pieSliceDepth='30' showBorder='0' formatNumberScale='0' enableRotation='1' showLabels='0' baseFont='Verdana' baseFontSize='10' baseFontColor='black'>");

                        xmlDataModal.Append(
                            "<chart   palette='5' captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='Todays PO Activity - Modality' bgcolor='#F0F0F0' pieSliceDepth='30' showBorder='0' formatNumberScale='0' enableRotation='1' showLabels='0' baseFont='Verdana' baseFontSize='10' baseFontColor='black'>");


                        foreach (DataRow dr in dt11.Rows)
                        {
                            xmlData.AppendFormat("<set label='{0}' value='{1}' />", dr["Modality"], dr["POCount"]);
                            xmlDataModal.AppendFormat("<set label='{0}' value='{1}' />", dr["Modality"], dr["POCount"]);
                        }

                        xmlDataModal.AppendFormat(
                            "<styles><definition><style name='myCaptionFont' type='font' size='16' bold='1' underline='1'/></definition>");
                        xmlDataModal.AppendFormat(
                            "<application><apply toObject='Caption' styles='myCaptionFont' /></application> </styles>");

                        xmlData.Append("</chart>");
                        xmlDataModal.Append("</chart>");

                        if (iCount == 0)
                        {
                            lChart1.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart4.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 1)
                        {
                            lChart2.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart5.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 2)
                        {
                            lChart3.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart6.Text =
                                FusionCharts.RenderChart("./FusionCharts/Column3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                    }
                }
                else if (g.GraphicID == 18 && Convert.ToInt64(ViewState["Hospital"]) > 0 && Convert.ToInt64(ViewState["Department"]) > 0)
                {
                    DataTable dt12 =
                        POProductRequisitionManager.GetPOProductsReqsGroupByVendorToday(Global.CurrentUser.UserID,
                                                                                        Convert.ToInt64(ViewState["Hospital"]),
                                                                                        Convert.ToInt64(ViewState["Department"]));

                    if (dt12.Rows.Count > 0)
                    {
                        Color[] c =
                            {
                                Color.Sienna,
                                Color.OliveDrab,
                                Color.Peru,
                                Color.Maroon,
                                Color.YellowGreen,
                                Color.Crimson,
                                Color.CornflowerBlue,
                                Color.Chocolate,
                                Color.Olive,
                                Color.DarkKhaki,
                                Color.PaleGoldenrod,
                                Color.Tan,
                                Color.Khaki,
                                Color.DarkGoldenrod,
                            };

                        StringBuilder xmlData = new StringBuilder();
                        StringBuilder xmlDataModal = new StringBuilder();

                        xmlData.Append(
                            "<chart palette='3' captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='Todays PO Activity - Vendor' bgcolor='#F0F0F0' showValues='0' showBorder='0' formatNumberScale='0' enableRotation='1' showLabels='0' baseFont='Verdana' baseFontSize='10' baseFontColor='black' enableSmartLabels='1' pieYScale='60'>");

                        xmlDataModal.Append(
                            "<chart   palette='3' captionPadding='0' chartTopMargin='0' chartBottomMargin='0' chartLeftMargin='0' chartRightMargin='0'  caption='Todays PO Activity - Vendor' bgcolor='#F0F0F0' showBorder='0' formatNumberScale='0' enableRotation='1' showLabels='0' baseFont='Verdana' baseFontSize='10' baseFontColor='black' enableSmartLabels='1' pieYScale='60'>");

                        int i = 0;

                        foreach (DataRow dr in dt12.Rows)
                        {
                            xmlData.AppendFormat(
                                "<set color='" + string.Format("{0:X2}{1:X2}{2:X2}", c[i].R, c[i].G, c[i].B) +
                                "' label='{0}' value='{1}' />", dr["Vendor"], dr["POCount"]);

                            xmlDataModal.AppendFormat(
                                "<set color='" + string.Format("{0:X2}{1:X2}{2:X2}", c[i].R, c[i].G, c[i].B) +
                                "' label='{0}' value='{1}' />", dr["Vendor"], dr["POCount"]);

                            i++;

                            if (i > 12)
                                i = 0;
                        }

                        xmlDataModal.AppendFormat(
                            "<styles><definition><style name='myCaptionFont' type='font' size='16' bold='1' underline='1'/></definition>");
                        xmlDataModal.AppendFormat(
                            "<application><apply toObject='Caption' styles='myCaptionFont' /></application> </styles>");

                        xmlData.Append("</chart>");
                        xmlDataModal.Append("</chart>");

                        if (iCount == 0)
                        {
                            lChart1.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart4.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 1)
                        {
                            lChart2.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart5.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                        else if (iCount == 2)
                        {
                            lChart3.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlData.ToString(),
                                                         iCount.ToString(),
                                                         "200", "120", false, false);
                            lChart6.Text =
                                FusionCharts.RenderChart("./FusionCharts/Pie3D.swf", "", xmlDataModal.ToString(),
                                                         iCount + "Modal", "600", "300", false, false);
                        }
                    }
                }
                iCount++;
            }
        }

        protected void OnHospitalDepartmentChange(object sender, EventArgs e)
        {
            RefreshPage(false);
        }

        private void RefreshPage(bool bForceRefresh)
        {
            if ((bForceRefresh) || (Convert.ToInt64(ViewState["Hospital"]) != Convert.ToInt64(ddlHospital.SelectedValue) ||
                Convert.ToInt64(ViewState["Department"]) != Convert.ToInt64(ddlDepartment.SelectedValue)))
            {
                ViewState["Hospital"] = ddlHospital.SelectedValue == "" ? 0 : Convert.ToInt64(ddlHospital.SelectedValue);
                ViewState["Department"] = ddlDepartment.SelectedValue == ""
                                              ? 0
                                              : Convert.ToInt64(ddlDepartment.SelectedValue);

                RefreshGrid();
            }
        }

        protected void OnArchive()
        {
            foreach(RepeaterItem ri in rptPOs.Items)
            {
                if (ri.ItemType == ListItemType.Item || ri.ItemType == ListItemType.AlternatingItem)
                {
                    CheckBox cb = (CheckBox)ri.FindControl("cbArchive");

                    if (((CheckBox)ri.FindControl("cbArchive")).Checked)
                    {
                        long lPOReqID = Convert.ToInt64(((HiddenField) ri.FindControl("hfPOReqID")).Value);

                        if (Global.CurrentUser.UserTypeID == (int)Entity.User.UserType.HospitalUser)
                            POProductRequisitionManager.UpdatePOReqProductsArchive(lPOReqID, cb.Checked);
                        else
                            POProductRequisitionManager.UpdatePOReqProductsVendorArchive(lPOReqID, cb.Checked);
                    }
                }
            }

            RefreshPage(true);
        }

        protected void OnRowClick(object sender, EventArgs e)
        {
            POProductRequisition poProductRequisition =
                            POProductRequisitionManager.GetPOProductRequisitionByID(
                                Convert.ToInt64(Request.Params.Get("__EVENTARGUMENT")), Global.CurrentUser.UserID);

            if (poProductRequisition.Completed && (poProductRequisition.ApprovalStatusID == Convert.ToInt32(POProductRequisition.ApprovalStatus.NotApproved)))
            {
                ApprovalRouting approvalRouting =
                    ApprovalRoutingManager.GetApproversByIDs(
                        poProductRequisition.POProdHospital.HospitalID,
                        poProductRequisition.POProdDepartment.DepartmentID,
                        poProductRequisition.POProdModality.ModalityID,
                        poProductRequisition.POProdVendor.UManufacturers[0].ManufacturerID);

                bool bAlternateApprover = AlternateApproverManager.IsUserAlternateApprover(Global.CurrentUser.UserID,
                                                                     approvalRouting.ApprovalRoutingID);
                if (approvalRouting.ARFirstApproverUser.UserID == Global.CurrentUser.UserID || bAlternateApprover || approvalRouting.AllAlternate)
                {
                    Response.Redirect("POReqProducts.aspx?rID=" + Request.Params.Get("__EVENTARGUMENT"));
                }
                else
                    Response.Redirect("ViewPOProduct.aspx?rID=" + Request.Params.Get("__EVENTARGUMENT"));
            }

            Response.Redirect("ViewPOProduct.aspx?rID=" + Request.Params.Get("__EVENTARGUMENT"));
        }
    }
}